@@ -1,14 +1,14 @@
 package TestApp::Controller::Root;
 
 use parent 'Catalyst::Controller::WrapCGI';
+use CGI ();
 
 __PACKAGE__->config->{namespace} = '';
 
 my $cgi = sub {
-    use CGI ':standard';
-
-    print header;
-    print 'foo:',param('foo'),' bar:',param('bar')
+    my $cgi = CGI->new;
+    print $cgi->header;
+    print 'foo:',$cgi->param('foo'),' bar:',$cgi->param('bar')
 };
 
 sub handle_cgi : Path('/cgi-bin/test.cgi') {
